componenttools.iterate_timeline_forward_from_component
======================================================

.. autofunction:: abjad.tools.componenttools.iterate_timeline_forward_from_component.iterate_timeline_forward_from_component
